"""This module is for the translation mapping data of the
following document:

Document file: svg_text.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# SvgText class": "# SvgText クラス",
    ##################################################
    "This page explains the `SvgText` class.": "このページでは`SvgText`クラスについて説明します。",
    ##################################################
    "## What class is this?": "## クラス概要",
    ##################################################
    "The `SvgText` class creates an SVG text object.": "`SvgText`クラスはSVGテキストのオブジェクトを生成します。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `SvgText` class constructor requires the `text` argument.": "`SvgText`クラスのコンストラクタは`text`引数の指定を必要とします。",  # noqa
    ##################################################
    "The constructor also accepts each font\'s and style\'s argument, such as the `font_size`, `font_family`, `fill_color`, and `bold`.": "コンストラクタでは`font_size`や`font_family`、`fill_color`、`bold`などのフォントやスタイルなどの引数を指定することもできます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nap.save_overall_html(dest_dir_path=\"svg_text_basic_usage/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nap.save_overall_html(dest_dir_path=\"svg_text_basic_usage/\")\n```",  # noqa
    ##################################################
    "## Note on the baseline of a text\'s y-coordinate": "## テキストのY座標の基準点に対する特記事項",
    ##################################################
    "The baseline of a text\'s y-coordinate is the text\'s bottom position (this is the specification of the SVG text).": "テキストのY座標の基準点はテキストの下部付近の位置となります（これはSVGテキストの仕様となります）。",  # noqa
    ##################################################
    "So if you specify `y=0` as the coordinate, you can see almost nothing of a text\'s content (barely see the bottom of the comma in the following example).": "そのためもしもY座標に`y=0`を指定した場合、テキストのコンテンツがほとんど見えなくなります（以下の例では辛うじてコンマの一部が確認できます）。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=0,\n    fill_color=ap.Color(\"#aaa\"),\n)\nap.save_overall_html(dest_dir_path=\"svg_text_note_on_the_y_baseline/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=0,\n    fill_color=ap.Color(\"#aaa\"),\n)\nap.save_overall_html(dest_dir_path=\"svg_text_note_on_the_y_baseline/\")\n```",  # noqa
    ##################################################
    "## text property interface example": "## text 属性のインターフェイス例",
    ##################################################
    "The `text` property updates or gets the instance\'s text.": "`text`属性ではインスタンスのテキストの更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.text = ap.String(\"Lorem ipsum\")\nap.save_overall_html(dest_dir_path=\"svg_text_text/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.text = ap.String(\"Lorem ipsum\")\nap.save_overall_html(dest_dir_path=\"svg_text_text/\")\n```",  # noqa
    ##################################################
    "## font_size property interface example": "## font_size 属性のインターフェイス例",
    ##################################################
    "The `font_size` property updates or gets the instance\'s font size.": "`font_size`属性ではインスタンスのフォントサイズの更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=34,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.font_size = ap.Int(24)\nap.save_overall_html(dest_dir_path=\"svg_text_font_size/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=34,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.font_size = ap.Int(24)\nap.save_overall_html(dest_dir_path=\"svg_text_font_size/\")\n```",  # noqa
    ##################################################
    "## font_family property interface example": "## font_family 属性のインターフェイス例",
    ##################################################
    "The `font_family` property updates or gets the instance\'s font family.": "`font_family`属性ではインスタンスのフォントファミリー（フォントの指定）の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "This property requires an `Array` of each font name `String`.": "この属性は各フォント名の`String`型の文字列を格納した`Array`型の配列を必要とします。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.font_family = ap.Array([ap.String(\"Impact\"), ap.String(\"Times New Roman\")])\nap.save_overall_html(dest_dir_path=\"svg_text_font_family/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.font_family = ap.Array([ap.String(\"Impact\"), ap.String(\"Times New Roman\")])\nap.save_overall_html(dest_dir_path=\"svg_text_font_family/\")\n```",  # noqa
    ##################################################
    "## x property interface example": "## x属性のインターフェイス例",
    ##################################################
    "The `x` property updates or gets the instance\'s x-coordinate:": "`x`属性ではX座標の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.x = ap.Number(50)\nap.save_overall_html(dest_dir_path=\"svg_text_x/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.x = ap.Number(50)\nap.save_overall_html(dest_dir_path=\"svg_text_x/\")\n```",  # noqa
    ##################################################
    "## y property interface example": "## y属性のインターフェイス例",
    ##################################################
    "The `y` property updates or gets the instance\'s y-coordinate:": "`y`属性ではY座標の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=70,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.y = ap.Number(45)\nap.save_overall_html(dest_dir_path=\"svg_text_y/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=70,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.y = ap.Number(45)\nap.save_overall_html(dest_dir_path=\"svg_text_y/\")\n```",  # noqa
    ##################################################
    "## fill_color property interface example": "## fill_color属性のインターフェイス例",
    ##################################################
    "The `fill_color` property updates or gets the instance\'s fill color:": "`fill_color`属性は塗りの色の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n)\nsvg_text.fill_color = ap.Color(\"#0af\")\nap.save_overall_html(dest_dir_path=\"svg_text_fill_color/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n)\nsvg_text.fill_color = ap.Color(\"#0af\")\nap.save_overall_html(dest_dir_path=\"svg_text_fill_color/\")\n```",  # noqa
    ##################################################
    "## fill_alpha property interface example": "## fill_alpha属性のインターフェイス例",
    ##################################################
    "The `fill_alpha` property updates or gets the instance\'s fill alpha (opacity):": "`fill_alpha`属性は塗りの透明度の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.fill_alpha = ap.Number(0.3)\nap.save_overall_html(dest_dir_path=\"svg_text_fill_alpha/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.fill_alpha = ap.Number(0.3)\nap.save_overall_html(dest_dir_path=\"svg_text_fill_alpha/\")\n```",  # noqa
    ##################################################
    "## line_color property interface example": "## line_color属性のインターフェイス例",
    ##################################################
    "The `line_color` property updates or gets the instance\'s line color:": "`line_color`属性では線の色の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=34,\n    font_size=24,\n    bold=True,\n    fill_color=ap.COLORLESS,\n    line_thickness=1,\n)\nsvg_text.line_color = ap.Color(\"#0af\")\nap.save_overall_html(dest_dir_path=\"svg_text_line_color/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=34,\n    font_size=24,\n    bold=True,\n    fill_color=ap.COLORLESS,\n    line_thickness=1,\n)\nsvg_text.line_color = ap.Color(\"#0af\")\nap.save_overall_html(dest_dir_path=\"svg_text_line_color/\")\n```",  # noqa
    ##################################################
    "## line_alpha property interface example": "## line_alpha属性のインターフェイス例",
    ##################################################
    "The `line_alpha` property updates or gets the instance\'s line alpha (opacity):": "`line_alpha`属性では線の透明度の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=34,\n    font_size=24,\n    bold=True,\n    fill_color=ap.COLORLESS,\n    line_color=ap.Color(\"#0af\"),\n    line_thickness=1,\n)\nsvg_text.line_alpha = ap.Number(0.3)\nap.save_overall_html(dest_dir_path=\"svg_text_line_alpha/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=34,\n    font_size=24,\n    bold=True,\n    fill_color=ap.COLORLESS,\n    line_color=ap.Color(\"#0af\"),\n    line_thickness=1,\n)\nsvg_text.line_alpha = ap.Number(0.3)\nap.save_overall_html(dest_dir_path=\"svg_text_line_alpha/\")\n```",  # noqa
    ##################################################
    "## line_thickness property interface example": "## line_thickness属性のインターフェイス例",
    ##################################################
    "The `line_thickness` property updates or gets the instance\'s line thickness (line width):": "`line_thickness`属性では線の幅の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=34,\n    font_size=24,\n    bold=True,\n    fill_color=ap.COLORLESS,\n    line_color=ap.Color(\"#0af\"),\n)\nsvg_text.line_thickness = ap.Int(3)\nap.save_overall_html(dest_dir_path=\"svg_text_line_thickness/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=34,\n    font_size=24,\n    bold=True,\n    fill_color=ap.COLORLESS,\n    line_color=ap.Color(\"#0af\"),\n)\nsvg_text.line_thickness = ap.Int(3)\nap.save_overall_html(dest_dir_path=\"svg_text_line_thickness/\")\n```",  # noqa
    ##################################################
    "## leading property interface example": "## leading 属性のインターフェイス例",
    ##################################################
    "The `leading` property updates or gets the instance\'s text leading (line height).": "`leading`属性ではインスタンスの行間の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=500,\n    stage_height=120,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Lorem ipsum dolor sit amet,\nconsectetur adipiscing elit,\n\"\n    \"sed do eiusmod tempor incididunt\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.leading = ap.Number(2.0)\n\nap.save_overall_html(dest_dir_path=\"svg_text_leading/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=500,\n    stage_height=120,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Lorem ipsum dolor sit amet,\nconsectetur adipiscing elit,\n\"\n    \"sed do eiusmod tempor incididunt\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.leading = ap.Number(2.0)\n\nap.save_overall_html(dest_dir_path=\"svg_text_leading/\")\n```",  # noqa
    ##################################################
    "## align property interface example": "## align 属性のインターフェイス例",
    ##################################################
    "The `align` property updates or gets the instance\'s horizontal text alignment (left, center, or right).": "`align`属性ではインスタンスの水平方向の行揃えの設定（左端、中央、右端）の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "This property requires the `SvgTextAlign` enum.": "この属性は`SvgTextAlign`のenumの値を必要とします。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=500,\n    stage_height=100,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Lorem ipsum dolor sit amet,\nconsectetur adipiscing elit,\n\"\n    \"sed do eiusmod tempor incididunt\",\n    x=250,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.align = ap.SvgTextAlign.CENTER\n\nap.save_overall_html(dest_dir_path=\"svg_text_align/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=500,\n    stage_height=100,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Lorem ipsum dolor sit amet,\nconsectetur adipiscing elit,\n\"\n    \"sed do eiusmod tempor incididunt\",\n    x=250,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.align = ap.SvgTextAlign.CENTER\n\nap.save_overall_html(dest_dir_path=\"svg_text_align/\")\n```",  # noqa
    ##################################################
    "Note: This property setting changes x coordinate baseline (position of `x=0`), as follows:": "特記事項: この属性はX座標の基準位置（`x=0`の位置）を以下のように変更します:",  # noqa
    ##################################################
    "- SvgTextAlign.CENTER: X coordinate baseline becomes the text\'s center position.": "- SvgTextAlign.CENTER: X座標の基準位置はテキストの中央位置になります。",  # noqa
    ##################################################
    "- SvgTextAlign.RIGHT: X coordinate baseline becomes the text\'s right position.": "- SvgTextAlign.RIGHT: X座標の基準位置はテキストの右端の位置になります。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nSTAGE_WIDTH: int = 500\nSTAGE_HEIGHT: int = 120\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=STAGE_WIDTH,\n    stage_height=STAGE_HEIGHT,\n    stage_elem_id=\"stage\",\n)\ncontainer_sprite: ap.Sprite = ap.Sprite()\ncontainer_sprite.x = ap.Number(STAGE_WIDTH / 2)\n\nvertical_x0_line: ap.Line = ap.Line(\n    start_point=ap.Point2D(0, 0),\n    end_point=ap.Point2D(0, STAGE_HEIGHT),\n    line_color=ap.Color(\"#666\"),\n    parent=container_sprite,\n)\nx0_text: ap.SvgText = ap.SvgText(\n    text=\"Text\'s x=0 position\",\n    fill_color=ap.Color(\"#666\"),\n    x=5,\n    y=20,\n    parent=container_sprite,\n)\n\nleft_align_sample_text: ap.SvgText = ap.SvgText(\n    text=\"Left align sample (default)\",\n    x=0,\n    y=52,\n    fill_color=ap.Color(\"#aaa\"),\n    parent=container_sprite,\n)\n\ncenter_align_sample_text: ap.SvgText = ap.SvgText(\n    text=\"Center align sample\",\n    x=0,\n    y=72,\n    fill_color=ap.Color(\"#aaa\"),\n    parent=container_sprite,\n)\ncenter_align_sample_text.align = ap.SvgTextAlign.CENTER\n\nright_align_sample_text: ap.SvgText = ap.SvgText(\n    text=\"Right align sample\",\n    x=0,\n    y=92,\n    fill_color=ap.Color(\"#aaa\"),\n    parent=container_sprite,\n)\nright_align_sample_text.align = ap.SvgTextAlign.RIGHT\n\nap.save_overall_html(dest_dir_path=\"svg_text_align_note/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nSTAGE_WIDTH: int = 500\nSTAGE_HEIGHT: int = 120\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=STAGE_WIDTH,\n    stage_height=STAGE_HEIGHT,\n    stage_elem_id=\"stage\",\n)\ncontainer_sprite: ap.Sprite = ap.Sprite()\ncontainer_sprite.x = ap.Number(STAGE_WIDTH / 2)\n\nvertical_x0_line: ap.Line = ap.Line(\n    start_point=ap.Point2D(0, 0),\n    end_point=ap.Point2D(0, STAGE_HEIGHT),\n    line_color=ap.Color(\"#666\"),\n    parent=container_sprite,\n)\nx0_text: ap.SvgText = ap.SvgText(\n    text=\"Text\'s x=0 position\",\n    fill_color=ap.Color(\"#666\"),\n    x=5,\n    y=20,\n    parent=container_sprite,\n)\n\nleft_align_sample_text: ap.SvgText = ap.SvgText(\n    text=\"Left align sample (default)\",\n    x=0,\n    y=52,\n    fill_color=ap.Color(\"#aaa\"),\n    parent=container_sprite,\n)\n\ncenter_align_sample_text: ap.SvgText = ap.SvgText(\n    text=\"Center align sample\",\n    x=0,\n    y=72,\n    fill_color=ap.Color(\"#aaa\"),\n    parent=container_sprite,\n)\ncenter_align_sample_text.align = ap.SvgTextAlign.CENTER\n\nright_align_sample_text: ap.SvgText = ap.SvgText(\n    text=\"Right align sample\",\n    x=0,\n    y=92,\n    fill_color=ap.Color(\"#aaa\"),\n    parent=container_sprite,\n)\nright_align_sample_text.align = ap.SvgTextAlign.RIGHT\n\nap.save_overall_html(dest_dir_path=\"svg_text_align_note/\")\n```",  # noqa
    ##################################################
    "## bold property interface example": "## bold 属性のインターフェイス例",
    ##################################################
    "The `bold` property updates or gets the instance\'s `bold` text setting.": "`bold`属性ではインスタンスの太字設定の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Bold style sample\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.bold = ap.Boolean(True)\nap.save_overall_html(dest_dir_path=\"svg_text_bold/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Bold style sample\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.bold = ap.Boolean(True)\nap.save_overall_html(dest_dir_path=\"svg_text_bold/\")\n```",  # noqa
    ##################################################
    "## italic property interface example": "## italic 属性のインターフェイス例",
    ##################################################
    "The `italic` property updates or gets the instance\'s `italic` style setting.": "`italic`属性ではインスタンスの斜体の設定の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Italic style sample\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.italic = ap.Boolean(True)\nap.save_overall_html(dest_dir_path=\"svg_text_italic/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Italic style sample\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\nsvg_text.italic = ap.Boolean(True)\nap.save_overall_html(dest_dir_path=\"svg_text_italic/\")\n```",  # noqa
    ##################################################
    "## rotation_around_center property interface example": "## rotation_around_center属性のインターフェイス例",  # noqa
    ##################################################
    "The `rotation_around_center` property updates or gets the instance\'s rotation value (0 to 359) from the center point:": "`rotation_around_center`属性ではインスタンスの中央座標での回転量（0～359）の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=100,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n    align=ap.SvgTextAlign.CENTER,\n)\n\n\ndef on_enter_frame(e: ap.EnterFrameEvent, optional: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.EnterFrameEvent\n        Event instance.\n    optional : dict\n        Optional argument dictionary.\n    \"\"\"\n    svg_text.rotation_around_center += 1\n\n\nstage.enter_frame(handler=on_enter_frame)\nap.save_overall_html(dest_dir_path=\"svg_txt_rotation_around_center/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=100,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n    align=ap.SvgTextAlign.CENTER,\n)\n\n\ndef on_enter_frame(e: ap.EnterFrameEvent, optional: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.EnterFrameEvent\n        Event instance.\n    optional : dict\n        Optional argument dictionary.\n    \"\"\"\n    svg_text.rotation_around_center += 1\n\n\nstage.enter_frame(handler=on_enter_frame)\nap.save_overall_html(dest_dir_path=\"svg_txt_rotation_around_center/\")\n```",  # noqa
    ##################################################
    "## set_rotation_around_point and get_rotation_around_point methods interface example": "## set_rotation_around_pointとget_rotation_around_pointメソッドのインターフェイス例",  # noqa
    ##################################################
    "The `set_rotation_around_point` method updates the instance\'s rotation value (0 to 359) from a specified point.": "`set_rotation_around_point`メソッドは指定された座標からのインスタンスの回転量（0～359）を更新します。",  # noqa
    ##################################################
    "Similarly, the `get_rotation_around_point` method gets the instance\'s rotation value (0 to 359) from a specified point:": "同様に、`get_rotation_around_point`メソッドでは指定された座標のインスタンスの回転量（0～359）を取得します:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=120,\n    stage_elem_id=\"stage\",\n)\nX: ap.Number = ap.Number(20)\nY: ap.Number = ap.Number(32)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=X,\n    y=Y,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_enter_frame(e: ap.EnterFrameEvent, optional: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.EnterFrameEvent\n        Event instance.\n    optional : dict\n        Optional argument dictionary.\n    \"\"\"\n    rotation: ap.Int = (\n        svg_text.get_rotation_around_point(\n            x=X,\n            y=Y,\n        )\n        + 1\n    )\n    svg_text.set_rotation_around_point(\n        rotation=rotation,\n        x=X,\n        y=Y,\n    )\n\n\nstage.enter_frame(handler=on_enter_frame)\nap.save_overall_html(dest_dir_path=\"svg_txt_rotation_around_point/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=120,\n    stage_elem_id=\"stage\",\n)\nX: ap.Number = ap.Number(20)\nY: ap.Number = ap.Number(32)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=X,\n    y=Y,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_enter_frame(e: ap.EnterFrameEvent, optional: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.EnterFrameEvent\n        Event instance.\n    optional : dict\n        Optional argument dictionary.\n    \"\"\"\n    rotation: ap.Int = (\n        svg_text.get_rotation_around_point(\n            x=X,\n            y=Y,\n        )\n        + 1\n    )\n    svg_text.set_rotation_around_point(\n        rotation=rotation,\n        x=X,\n        y=Y,\n    )\n\n\nstage.enter_frame(handler=on_enter_frame)\nap.save_overall_html(dest_dir_path=\"svg_txt_rotation_around_point/\")\n```",  # noqa
    ##################################################
    "## Scale-related interfaces note": "## 拡縮関係のインターフェイスに対する特記事項",
    ##################################################
    "The scale-related interfaces are not recommended as the display may become distorted depending on the settings.": "拡縮関係のインターフェイスは設定次第では表示が崩れたりするため利用は非推奨です。",  # noqa
    ##################################################
    "## scale_x_from_center property interface example": "## scale_x_from_center属性のインターフェイス例",  # noqa
    ##################################################
    "The `scale_x_from_center` property updates or gets the instance\'s scale-x from the center point:": "`scale_x_from_center`属性ではインスタンスの中央座標でのX軸の拡縮値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ndirection: ap.Int = ap.Int(-1)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_enter_frame(e: ap.EnterFrameEvent, optional: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.EnterFrameEvent\n        Event instance.\n    optional : dict\n        Optional argument dictionary.\n    \"\"\"\n    scale: ap.Number = svg_text.scale_x_from_center\n    with ap.If(scale > 1):\n        direction.value = -1\n    with ap.If(scale <= 0.3):\n        direction.value = 1\n    scale += direction * 0.005\n    svg_text.scale_x_from_center = scale\n\n\nstage.enter_frame(handler=on_enter_frame)\nap.save_overall_html(dest_dir_path=\"svg_txt_scale_x_from_center/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ndirection: ap.Int = ap.Int(-1)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_enter_frame(e: ap.EnterFrameEvent, optional: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.EnterFrameEvent\n        Event instance.\n    optional : dict\n        Optional argument dictionary.\n    \"\"\"\n    scale: ap.Number = svg_text.scale_x_from_center\n    with ap.If(scale > 1):\n        direction.value = -1\n    with ap.If(scale <= 0.3):\n        direction.value = 1\n    scale += direction * 0.005\n    svg_text.scale_x_from_center = scale\n\n\nstage.enter_frame(handler=on_enter_frame)\nap.save_overall_html(dest_dir_path=\"svg_txt_scale_x_from_center/\")\n```",  # noqa
    ##################################################
    "## set_scale_x_from_point and get_scale_x_from_point methods interface example": "## set_scale_x_from_pointとget_scale_x_from_pointメソッドのインターフェイス例",  # noqa
    ##################################################
    "The `set_scale_x_from_point` method updates the instance\'s scale-x from a specified point.": "`set_scale_x_from_point`メソッドは指定されたX座標を基準としてX軸の拡縮値を更新します。",  # noqa
    ##################################################
    "Similarly, the `get_scale_x_from_point` method gets the instance\'s scale-x from a specified point:": "同様に、`get_scale_x_from_point`メソッドでは指定されたX座標を基準としたX軸の拡縮値を取得します:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nX: ap.Number = ap.Number(20)\ndirection: ap.Int = ap.Int(-1)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=X,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_enter_frame(e: ap.EnterFrameEvent, optional: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.EnterFrameEvent\n        Event instance.\n    optional : dict\n        Optional argument dictionary.\n    \"\"\"\n    scale: ap.Number = svg_text.get_scale_x_from_point(x=X)\n    with ap.If(scale > 1):\n        direction.value = -1\n    with ap.If(scale <= 0.3):\n        direction.value = 1\n    scale += direction * 0.005\n    svg_text.set_scale_x_from_point(scale_x=scale, x=X)\n\n\nstage.enter_frame(handler=on_enter_frame)\nap.save_overall_html(dest_dir_path=\"svg_txt_scale_x_from_point/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nX: ap.Number = ap.Number(20)\ndirection: ap.Int = ap.Int(-1)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=X,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_enter_frame(e: ap.EnterFrameEvent, optional: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.EnterFrameEvent\n        Event instance.\n    optional : dict\n        Optional argument dictionary.\n    \"\"\"\n    scale: ap.Number = svg_text.get_scale_x_from_point(x=X)\n    with ap.If(scale > 1):\n        direction.value = -1\n    with ap.If(scale <= 0.3):\n        direction.value = 1\n    scale += direction * 0.005\n    svg_text.set_scale_x_from_point(scale_x=scale, x=X)\n\n\nstage.enter_frame(handler=on_enter_frame)\nap.save_overall_html(dest_dir_path=\"svg_txt_scale_x_from_point/\")\n```",  # noqa
    ##################################################
    "## flip_x property interface example": "## flip_x属性のインターフェイス例",
    ##################################################
    "The `flip_x` property updates or gets the instance\'s flip-x (reflecting state) boolean value:": "`flip_x`属性ではインスタンスのX軸の反転状況の真偽値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_timer(e: ap.TimerEvent, options: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional argument dictionary.\n    \"\"\"\n    svg_text.flip_x = svg_text.flip_x.not_\n\n\nap.Timer(handler=on_timer, delay=1000).start()\nap.save_overall_html(dest_dir_path=\"svg_txt_flip_x/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_timer(e: ap.TimerEvent, options: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional argument dictionary.\n    \"\"\"\n    svg_text.flip_x = svg_text.flip_x.not_\n\n\nap.Timer(handler=on_timer, delay=1000).start()\nap.save_overall_html(dest_dir_path=\"svg_txt_flip_x/\")\n```",  # noqa
    ##################################################
    "## flip_y property interface example": "## flip_y属性のインターフェイス例",
    ##################################################
    "The `flip_y` property updates or gets the instance\'s flip-y (reflecting state) boolean value:": "`flip_y`属性ではインスタンスのX軸の反転状況の真偽値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_timer(e: ap.TimerEvent, options: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional argument dictionary.\n    \"\"\"\n    svg_text.flip_y = svg_text.flip_y.not_\n\n\nap.Timer(handler=on_timer, delay=1000).start()\nap.save_overall_html(dest_dir_path=\"svg_txt_flip_y/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText(\n    text=\"Hello, world!\",\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\n\ndef on_timer(e: ap.TimerEvent, options: dict) -> None:\n    \"\"\"\n    The handler to handle a timer event.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional argument dictionary.\n    \"\"\"\n    svg_text.flip_y = svg_text.flip_y.not_\n\n\nap.Timer(handler=on_timer, delay=1000).start()\nap.save_overall_html(dest_dir_path=\"svg_txt_flip_y/\")\n```",  # noqa
    ##################################################
    "## SvgText constructor API": "## SvgText クラスのコンストラクタのAPI",
    ##################################################
    "<span class=\"inconspicuous-txt\">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>": "<span class=\"inconspicuous-txt\">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>",  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "The class for an SVG text.<hr>": "SVGテキストのためのクラスです。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `text`: Union[str, String]": "- `text`: Union[str, String]",
    ##################################################
    "  - A text to use in this class.": "  - このクラスで使用するテキスト。",
    ##################################################
    "- `font_size`: Union[int, Int], optional": "- `font_size`: Union[int, Int], optional",  # noqa
    ##################################################
    "  - A font-size setting.": "  - フォントサイズ設定。",
    ##################################################
    "- `font_family`: Optional[Union[Array[String], List[str]]], optional": "- `font_family`: Optional[Union[Array[String], List[str]]], optional",  # noqa
    ##################################################
    "  - A font-family setting. Each string in an array needs to be a font name (e.g., `Times New Roman`).": "  - フォントファミリー設定。配列内の各文字列には個別のフォント名を指定する必要があります（例: `Times New Roman`）。",  # noqa
    ##################################################
    "- `x`: float or Number, optional": "- `x`: float or Number, optional",
    ##################################################
    "  - X-coordinate to start drawing.": "  - 描画を開始するX座標。",
    ##################################################
    "- `y`: float or Number, optional": "- `y`: float or Number, optional",
    ##################################################
    "  - Y-coordinate to start drawing (please see also the `Notes` section).": "  - 描画を開始するY座標（`特記事項`の節も確認をお願いします）。",  # noqa
    ##################################################
    "- `fill_color`: Color": "- `fill_color`: Color",
    ##################################################
    "  - A fill-color setting.": "  - 塗りの色の設定。",
    ##################################################
    "- `fill_alpha`: float or Number, optional": "- `fill_alpha`: float or Number, optional",  # noqa
    ##################################################
    "  - A fill-alpha setting.": "  - 塗りの透明度の設定。",
    ##################################################
    "- `line_color`: Color, optional": "- `line_color`: Color, optional",
    ##################################################
    "  - A line-color setting.": "  - 線の色の設定。",
    ##################################################
    "- `line_alpha`: float or Number, optional": "- `line_alpha`: float or Number, optional",  # noqa
    ##################################################
    "  - A line-alpha setting.": "  - 線の透明度の設定。",
    ##################################################
    "- `line_thickness`: int or Int, optional": "- `line_thickness`: int or Int, optional",  # noqa
    ##################################################
    "  - A line-thickness (line-width) setting.": "  - 線幅の設定。",
    ##################################################
    "- `leading`: float or Number, optional": "- `leading`: float or Number, optional",
    ##################################################
    "  - A text-leading size.": "  - テキストの行間のサイズ。",
    ##################################################
    "- `align`: SvgTextAlign, default SvgTextAlign.LEFT": "- `align`: SvgTextAlign, default SvgTextAlign.LEFT",  # noqa
    ##################################################
    "  - A text-align setting.": "  - テキストの行揃えの設定。",
    ##################################################
    "- `bold`: Union[bool, Boolean], optional": "- `bold`: Union[bool, Boolean], optional",  # noqa
    ##################################################
    "  - A boolean, whether this text is a bold style or not.": "  - テキストに太字のスタイル設定を行うかどうかの真偽値。",  # noqa
    ##################################################
    "- `italic`: Union[bool, Boolean], optional": "- `italic`: Union[bool, Boolean], optional",  # noqa
    ##################################################
    "  - A boolean, whether a text is an italic style or not (normal).": "  - テキストを斜体表示のスタイル設定を行うかどうかの真偽値。",  # noqa
    ##################################################
    "- `parent`: ChildMixIn or None, optional": "- `parent`: ChildMixIn or None, optional",  # noqa
    ##################################################
    "  - A parent instance to add this instance. If the specified value is None, this interface uses a stage instance.": "  - このインスタンスを追加する親のインスタンス。もしもNoneが指定された場合、このインスタンスはステージのインスタンスへと追加されます。",  # noqa
    ##################################################
    "- `variable_name_suffix`: str, optional": "- `variable_name_suffix`: str, optional",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Notes]**": "**[特記事項]**",
    ##################################################
    " ・SvgText\'s y-coordinate zero-position starts at the bottom of a text. So if you set y=0, a text becomes almost invisible.<hr>": " ・SVGTextクラスの座標の0の位置はテキストの下部からスタートします。そのためもしもy=0を指定した場合、テキストはほとんど見えない状態になります。<hr>",  # noqa
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     background_color=ap.Color(\"#333\"),\n...     stage_width=200,\n...     stage_height=50,\n...     stage_elem_id=\"stage\",\n... )\n>>> svg_text: ap.SvgText = ap.SvgText(\n...     text=\"Hello, world!\",\n...     font_size=20,\n...     fill_color=ap.Color(\"#0af\"),\n... )\n>>> svg_text.text\nString(\"Hello, world!\")\n\n>>> svg_text.font_size\nInt(20)\n\n>>> svg_text.fill_color\nColor(\"#00aaff\")\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     background_color=ap.Color(\"#333\"),\n...     stage_width=200,\n...     stage_height=50,\n...     stage_elem_id=\"stage\",\n... )\n>>> svg_text: ap.SvgText = ap.SvgText(\n...     text=\"Hello, world!\",\n...     font_size=20,\n...     fill_color=ap.Color(\"#0af\"),\n... )\n>>> svg_text.text\nString(\"Hello, world!\")\n\n>>> svg_text.font_size\nInt(20)\n\n>>> svg_text.fill_color\nColor(\"#00aaff\")\n```",  # noqa
}



"""The class implementation for the outlined `import_contacts` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialImportContactsOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `import_contacts` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M21 5c-1.11-.35-2.33-.5-3.5-.5-1.95 0-4.05.4-5.5 1.5-1.45-1.1-3.55-1.5-5.5-1.5S2.45 4.9 1 6v14.65c0 .25.25.5.5.5.1 0 .15-.05.25-.05C3.1 20.45 5.05 20 6.5 20c1.95 0 4.05.4 5.5 1.5 1.35-.85 3.8-1.5 5.5-1.5 1.65 0 3.35.3 4.75 1.05.1.05.15.05.25.05.25 0 .5-.25.5-.5V6c-.6-.45-1.25-.75-2-1zm0 13.5c-1.1-.35-2.3-.5-3.5-.5-1.7 0-4.15.65-5.5 1.5V8c1.35-.85 3.8-1.5 5.5-1.5 1.2 0 2.4.15 3.5.5v11.5z"/></svg>'  # noqa



"""The class implementation for the `contact_page` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialContactPageIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `contact_page` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><rect fill="none" height="24" width="24"/><path d="M14,2H6C4.9,2,4,2.9,4,4v16c0,1.1,0.9,2,2,2h12c1.1,0,2-0.9,2-2V8L14,2z M12,10c1.1,0,2,0.9,2,2c0,1.1-0.9,2-2,2s-2-0.9-2-2 C10,10.9,10.9,10,12,10z M16,18H8v-0.57c0-0.81,0.48-1.53,1.22-1.85C10.07,15.21,11.01,15,12,15c0.99,0,1.93,0.21,2.78,0.58 C15.52,15.9,16,16.62,16,17.43V18z"/></svg>'  # noqa



"""The mix-in class implementation for `SvgForeignObjectChild`-related
interfaces.
"""

from typing import Union

from apysc._display.svg_foreign_object_child import SvgForeignObjectChild
from apysc._type.string import String


class SvgForeignObjectChildMixIn:
    _svg_foreign_object_child: SvgForeignObjectChild

    def _initialize_svg_foreign_object_child(
        self,
        html_str: Union[str, String],
        variable_name_suffix: str = "",
    ) -> None:
        """
        Initialize the `_svg_foreign_object_child` attribute.

        Parameters
        ----------
        html_str : Union[str, String]
            A HTML string.
        variable_name_suffix : str, optional
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.
        """
        from apysc._display.add_foreign_object_child_mixin import (
            AddForeignObjectChildMixIn,
        )

        if not isinstance(self, AddForeignObjectChildMixIn):
            raise TypeError(
                "This method can only be called by an "
                "`AddForeignObjectChildMixIn`'s instance."
            )
        self._svg_foreign_object_child = SvgForeignObjectChild(
            html_str=html_str,
            variable_name_suffix=variable_name_suffix,
        )
        self._add_foreign_object_child(child=self._svg_foreign_object_child)



"""The class implementation for the outlined `build_circle` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialBuildCircleOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `build_circle` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><path d="M12,2C6.48,2,2,6.48,2,12c0,5.52,4.48,10,10,10s10-4.48,10-10 C22,6.48,17.52,2,12,2z M12,20c-4.41,0-8-3.59-8-8c0-4.41,3.59-8,8-8s8,3.59,8,8C20,16.41,16.41,20,12,20z" fill-rule="evenodd"/><path d="M13.49,11.38c0.43-1.22,0.17-2.64-0.81-3.62c-1.11-1.11-2.79-1.3-4.1-0.59 l2.35,2.35l-1.41,1.41L7.17,8.58c-0.71,1.32-0.52,2.99,0.59,4.1c0.98,0.98,2.4,1.24,3.62,0.81l3.41,3.41c0.2,0.2,0.51,0.2,0.71,0 l1.4-1.4c0.2-0.2,0.2-0.51,0-0.71L13.49,11.38z" fill-rule="evenodd"/></g></g></svg>'  # noqa



"""The class implementation for the `app_registration` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialAppRegistrationIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `app_registration` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><rect height="4" width="4" x="10" y="4"/><rect height="4" width="4" x="4" y="16"/><rect height="4" width="4" x="4" y="10"/><rect height="4" width="4" x="4" y="4"/><polygon points="14,12.42 14,10 10,10 10,14 12.42,14"/><path d="M20.88,11.29l-1.17-1.17c-0.16-0.16-0.42-0.16-0.58,0L18.25,11L20,12.75l0.88-0.88C21.04,11.71,21.04,11.45,20.88,11.29z"/><polygon points="11,18.25 11,20 12.75,20 19.42,13.33 17.67,11.58"/><rect height="4" width="4" x="16" y="4"/></g></g></svg>'  # noqa



"""The enum definition for the material design brightness (light or dark).
"""

from enum import Enum


class MaterialBrightness(Enum):
    """The enum class for the material design brightness (light or dark)."""

    LIGHT = "light"
    DARK = "dark"



"""This module is for the translation mapping data of the
following document:

Document file: svg_text_span.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# SvgTextSpan class": "# SvgTextSpan クラス",
    ##################################################
    "This page explains the `SvgTextSpan` class.": "このページでは`SvgTextSpan`クラスについて説明します。",
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `SvgTextSpan` is the class for an SVG text-span (the child class of `SvgText`).": "`SvgTextSpan`は`SvgText`の子となるテキスト要素を作成するためのクラスです。",  # noqa
    ##################################################
    "You can create an `SvgText` instance with multiple `SvgTextSpan` class instances and set different text styles.": "複数の`SvgTextSpan`クラスのインスタンスを使ってそれぞれに異なるテキストのスタイルを設定した状態の`SvgText`のインスタンスを作成することができます。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `SvgTextSpan` class constructor requires the `text` argument.": "`SvgTextSpan`クラスのコンストラクタには`text`引数を必要とします。",  # noqa
    ##################################################
    "The constructor also accepts each font\'s and style\'s argument, such as the `font_size`, `font_family`, `fill_color`, and `bold`.": "コンストラクタでは`font_size`や`font_family`、`fill_color`、`bold`などの各スタイル設定の引数を受け付けます。",  # noqa
    ##################################################
    "If you skip the style settings\' arguments, these settings become the parent SvgText\'s styles.": "もしもそれらのスタイル設定の引数指定を省略した場合、親のSVGTextのインスタンスのスタイルが反映されます。",  # noqa
    ##################################################
    "You can use `SvgTextSpan` instances to create an `SvgText` instance with the `create_with_svg_text_spans` class method.": "また、複数の`SvgTextSpan`のインスタンスを使って`SvgText`のインスタンスの作成するには`create_with_svg_text_spans`のクラスメソッドを使うことで対応ができます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[\n        ap.SvgTextSpan(text=\"Lorem \"),\n        ap.SvgTextSpan(text=\"ipsum \", font_size=20, fill_color=ap.Color(\"#0af\")),\n        ap.SvgTextSpan(text=\"dolor \", font_size=12),\n    ],\n    fill_color=ap.Color(\"#aaa\"),\n    font_size=16,\n    x=20,\n    y=32,\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_basic_usage/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[\n        ap.SvgTextSpan(text=\"Lorem \"),\n        ap.SvgTextSpan(text=\"ipsum \", font_size=20, fill_color=ap.Color(\"#0af\")),\n        ap.SvgTextSpan(text=\"dolor \", font_size=12),\n    ],\n    fill_color=ap.Color(\"#aaa\"),\n    font_size=16,\n    x=20,\n    y=32,\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_basic_usage/\")\n```",  # noqa
    ##################################################
    "## Notes of the line breaking": "## 改行に対する特記事項",
    ##################################################
    "The `SvgTextSpan` class ignores line breaks.": "`SvgTextSpan`クラスは改行設定を無視します。",
    ##################################################
    "For instance, the following example\'s text contains a line break (`\n`), but the text line becomes a single line.": "例えば、以下の例では改行用の文字列（`\n`）を含んでいますがテキストの行は単一行になっています。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[\n        ap.SvgTextSpan(text=\"Lorem \n\"),\n        ap.SvgTextSpan(text=\"ipsum \n\"),\n        ap.SvgTextSpan(text=\"dolor\"),\n    ],\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_notes_of_the_line_break/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[\n        ap.SvgTextSpan(text=\"Lorem \n\"),\n        ap.SvgTextSpan(text=\"ipsum \n\"),\n        ap.SvgTextSpan(text=\"dolor\"),\n    ],\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_notes_of_the_line_break/\")\n```",  # noqa
    ##################################################
    "If you want to add a line break, please use the `SvgText` class (not the `SvgTextSpan`) or create multiple `SvgText` instances.": "もしも改行を加えたい場合には`SvgTextSpan`クラスではなく`SvgText`クラスを使用するか、もしくは複数のインスタンスを作成して対応をお願いします。",  # noqa
    ##################################################
    "## text property interface example": "## text 属性のインターフェイス例",
    ##################################################
    "The `text` property updates or gets the instance\'s text.": "`text`属性ではインスタンスのテキストの更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.text = ap.String(\"dolor\")\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_text/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.text = ap.String(\"dolor\")\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_text/\")\n```",  # noqa
    ##################################################
    "## font_size property interface example": "## font_size 属性のインターフェイス例",
    ##################################################
    "The `font_size` property updates or gets the instance\'s font size.": "`font_size`属性ではインスタンスのフォントサイズの更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.font_size = ap.Int(25)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_font_size/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.font_size = ap.Int(25)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_font_size/\")\n```",  # noqa
    ##################################################
    "## font_family property interface example": "## font_family 属性のインターフェイス例",
    ##################################################
    "The `font_family` property updates or gets the instance\'s font family.": "`font_family`属性ではインスタンスのフォントファミリー（フォントの指定）の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "This property requires an `Array` of each font name `String`.": "この属性は各フォント名の`String`型の文字列を格納した`Array`型の配列を必要とします。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.font_family = ap.Array([ap.String(\"Impact\"), ap.String(\"Arial\")])\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_font_family/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.font_family = ap.Array([ap.String(\"Impact\"), ap.String(\"Arial\")])\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_font_family/\")\n```",  # noqa
    ##################################################
    "## fill_color property interface example": "## fill_color属性のインターフェイス例",
    ##################################################
    "The `fill_color` property updates or gets the instance\'s fill color:": "`fill_color`属性は塗りの色の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.fill_color = ap.Color(\"#0af\")\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_fill_color/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.fill_color = ap.Color(\"#0af\")\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_fill_color/\")\n```",  # noqa
    ##################################################
    "## fill_alpha property interface example": "## fill_alpha属性のインターフェイス例",
    ##################################################
    "The `fill_alpha` property updates or gets the instance\'s fill alpha (opacity):": "`fill_alpha`属性は塗りの透明度の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.fill_alpha = ap.Number(0.3)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_fill_alpha/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.fill_alpha = ap.Number(0.3)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_fill_alpha/\")\n```",  # noqa
    ##################################################
    "## line_color property interface example": "## line_color属性のインターフェイス例",
    ##################################################
    "The `line_color` property updates or gets the instance\'s line color:": "`line_color`属性では線の色の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"Lorem \", line_thickness=1, font_size=20, bold=True\n)\ntext_span_1.line_color = ap.Color(\"#aaa\")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"ipsum\", line_thickness=1, font_size=20, bold=True\n)\ntext_span_2.line_color = ap.Color(\"#0af\")\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.COLORLESS,\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_line_color/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"Lorem \", line_thickness=1, font_size=20, bold=True\n)\ntext_span_1.line_color = ap.Color(\"#aaa\")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"ipsum\", line_thickness=1, font_size=20, bold=True\n)\ntext_span_2.line_color = ap.Color(\"#0af\")\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.COLORLESS,\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_line_color/\")\n```",  # noqa
    ##################################################
    "## line_alpha property interface example": "## line_alpha属性のインターフェイス例",
    ##################################################
    "The `line_alpha` property updates or gets the instance\'s line alpha (opacity):": "`line_alpha`属性では線の透明度の値の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"Lorem \",\n    line_color=ap.Color(\"#0af\"),\n    line_thickness=1,\n    font_size=20,\n    bold=True,\n)\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"ipsum\",\n    line_color=ap.Color(\"#0af\"),\n    line_thickness=1,\n    font_size=20,\n    bold=True,\n)\ntext_span_2.line_alpha = ap.Number(0.3)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.COLORLESS,\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_line_alpha/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"Lorem \",\n    line_color=ap.Color(\"#0af\"),\n    line_thickness=1,\n    font_size=20,\n    bold=True,\n)\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"ipsum\",\n    line_color=ap.Color(\"#0af\"),\n    line_thickness=1,\n    font_size=20,\n    bold=True,\n)\ntext_span_2.line_alpha = ap.Number(0.3)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.COLORLESS,\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_line_alpha/\")\n```",  # noqa
    ##################################################
    "## line_thickness property interface example": "## line_thickness属性のインターフェイス例",
    ##################################################
    "The `line_thickness` property updates or gets the instance\'s line thickness (line width):": "`line_thickness`属性では線の幅の更新もしくは取得を行えます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"Lorem \",\n    line_color=ap.Color(\"#0af\"),\n    font_size=20,\n    bold=True,\n)\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"ipsum\",\n    line_color=ap.Color(\"#0af\"),\n    font_size=20,\n    bold=True,\n)\ntext_span_1.line_thickness = ap.Int(3)\ntext_span_2.line_thickness = ap.Int(3)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.COLORLESS,\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_line_thickness/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"Lorem \",\n    line_color=ap.Color(\"#0af\"),\n    font_size=20,\n    bold=True,\n)\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(\n    text=\"ipsum\",\n    line_color=ap.Color(\"#0af\"),\n    font_size=20,\n    bold=True,\n)\ntext_span_1.line_thickness = ap.Int(3)\ntext_span_2.line_thickness = ap.Int(3)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.COLORLESS,\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_line_thickness/\")\n```",  # noqa
    ##################################################
    "## bold property interface example": "## bold 属性のインターフェイス例",
    ##################################################
    "The `bold` property updates or gets the instance\'s `bold` text setting.": "`bold`属性ではインスタンスの太字設定の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.bold = ap.Boolean(True)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_bold/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.bold = ap.Boolean(True)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_bold/\")\n```",  # noqa
    ##################################################
    "## italic property interface example": "## italic 属性のインターフェイス例",
    ##################################################
    "The `italic` property updates or gets the instance\'s `italic` style setting.": "`italic`属性ではインスタンスの斜体の設定の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.italic = ap.Boolean(True)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_italic/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.italic = ap.Boolean(True)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_italic/\")\n```",  # noqa
    ##################################################
    "## delta_x property interface example": "## delta_x 属性のインターフェイス例",
    ##################################################
    "The `delta_x` property updates or gets the instance\'s delta-x (x-coordinate adjustment).": "`delta_x`属性ではインスタンスのX座標の調整値の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.delta_x = ap.Number(-20)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_delta_x/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=50,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum\")\ntext_span_2.delta_x = ap.Number(-20)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_delta_x/\")\n```",  # noqa
    ##################################################
    "## delta_y property interface example": "## delta_y 属性のインターフェイス例",
    ##################################################
    "The `delta_y` property updates or gets the instance\'s delta-y (y-coordinate adjustment).": "`delta_y`属性ではインスタンスのY座標の調整値の更新もくしは取得を行えます。",  # noqa
    ##################################################
    "Note: This setting inherits a y-coordinate from the previous `SvgTextSpan` instance.": "特記事項: この設定は直前の`SvgTextSpan`インスタンスの設定を引き継ぎます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=80,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum \")\ntext_span_3: ap.SvgTextSpan = ap.SvgTextSpan(text=\"dolar\")\n\ntext_span_2.delta_y = ap.Number(10)\ntext_span_3.delta_y = ap.Number(10)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_delta_y/\")\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color(\"#333\"),\n    stage_width=200,\n    stage_height=80,\n    stage_elem_id=\"stage\",\n)\ntext_span_1: ap.SvgTextSpan = ap.SvgTextSpan(text=\"Lorem \")\ntext_span_2: ap.SvgTextSpan = ap.SvgTextSpan(text=\"ipsum \")\ntext_span_3: ap.SvgTextSpan = ap.SvgTextSpan(text=\"dolar\")\n\ntext_span_2.delta_y = ap.Number(10)\ntext_span_3.delta_y = ap.Number(10)\n\nsvg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n    text_spans=[text_span_1, text_span_2],\n    font_size=16,\n    x=20,\n    y=32,\n    fill_color=ap.Color(\"#aaa\"),\n)\n\nap.save_overall_html(dest_dir_path=\"svg_txt_span_delta_y/\")\n```",  # noqa
    ##################################################
    "## SvgTextSpan constructor API": "## SvgTextSpan クラスのコンストラクタのAPI",
    ##################################################
    "<span class=\"inconspicuous-txt\">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>": "<span class=\"inconspicuous-txt\">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>",  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "The class for an SVG text-span (the child class of `SvgText`).<hr>": "`SvgText`の子となるSVGのtext-span要素のためのクラスです。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `text`: Union[str, String]": "- `text`: Union[str, String]",
    ##################################################
    "  - A text to use in this class.": "  - このクラスで使用するテキスト。",
    ##################################################
    "- `font_size`: Optional[Union[int, Int]], optional": "- `font_size`: Optional[Union[int, Int]], optional",  # noqa
    ##################################################
    "  - A font-size setting.": "  - フォントサイズ設定。",
    ##################################################
    "- `font_family`: Optional[Union[Array[String], List[str]]], optional": "- `font_family`: Optional[Union[Array[String], List[str]]], optional",  # noqa
    ##################################################
    "  - A font-family setting. Each string in an array needs to be a font name (e.g., `Times New Roman`).": "  - フォントファミリー設定。配列内の各文字列には個別のフォント名を指定する必要があります（例: `Times New Roman`）。",  # noqa
    ##################################################
    "- `fill_color`: Optional[Color], optional": "- `fill_color`: Optional[Color], optional",  # noqa
    ##################################################
    "  - A fill-color setting.": "  - 塗りの色の設定。",
    ##################################################
    "- `fill_alpha`: Optional[Union[float, Number]], optional": "- `fill_alpha`: Optional[Union[float, Number]], optional",  # noqa
    ##################################################
    "  - A fill-alpha setting.": "  - 塗りの透明度の設定。",
    ##################################################
    "- `line_color`: Optional[Color], optional": "- `line_color`: Optional[Color], optional",  # noqa
    ##################################################
    "  - A line-color setting.": "  - 線の色の設定。",
    ##################################################
    "- `line_alpha`: Optional[Union[float, Number]], optional": "- `line_alpha`: Optional[Union[float, Number]], optional",  # noqa
    ##################################################
    "  - A line-alpha setting.": "  - 線の透明度の設定。",
    ##################################################
    "- `line_thickness`: Optional[Union[int, Int]], optional": "- `line_thickness`: Optional[Union[int, Int]], optional",  # noqa
    ##################################################
    "  - A line-thickness (line-width) to set.": "  - 設定の線幅。",
    ##################################################
    "- `bold`: Optional[Union[bool, Boolean]], optional": "- `bold`: Optional[Union[bool, Boolean]], optional",  # noqa
    ##################################################
    "  - A boolean, whether this text is a bold style or not.": "  - テキストに太字のスタイル設定を行うかどうかの真偽値。",  # noqa
    ##################################################
    "- `italic`: Optional[Union[bool, Boolean]], optional": "- `italic`: Optional[Union[bool, Boolean]], optional",  # noqa
    ##################################################
    "  - A boolean, whether a text is an italic style or not (normal).": "  - テキストを斜体表示のスタイル設定を行うかどうかの真偽値。",  # noqa
    ##################################################
    "- `delta_x`: Union[float, Number], optional": "- `delta_x`: Union[float, Number], optional",  # noqa
    ##################################################
    "  - A coordinate delta-x setting. Notes: This setting also changes a coordinate of subsequent `SvgTextSpan`\'s instance.": "  - X座標の調整値の設定。特記事項 : この設定は後に続く`SvgTextSpan`のインスタンスの座標も変更します。",  # noqa
    ##################################################
    "- `delta_y`: Union[float, Number], optional": "- `delta_y`: Union[float, Number], optional",  # noqa
    ##################################################
    "  - A coordinate delta-y setting. Notes: This setting also changes a coordinate of subsequent `SvgTextSpan`\'s instance.": "  - Y座標の調整値の設定。特記事項 : この設定は後に続く`SvgTextSpan`のインスタンスの座標も更新します。",  # noqa
    ##################################################
    "- `variable_name_suffix`: str, optional": "- `variable_name_suffix`: str, optional",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Notes]**": "**[特記事項]**",
    ##################################################
    " ・If style settings are `None`, its styles inherit parent style settings.<hr>": " ・もしも各種スタイル設定に`None`が指定された場合、そのスタイルは親のスタイル設定を引き継ぎます。<hr>",  # noqa
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     background_color=ap.Color(\"#333\"), stage_width=200, stage_height=50\n... )\n>>> svg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n...     text_spans=[\n...         ap.SvgTextSpan(text=\"Hello, \"),\n...         ap.SvgTextSpan(text=\"Hello, \", font_size=14),\n...     ],\n...     font_size=20,\n...     fill_color=ap.Color(\"#0af\"),\n... )\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     background_color=ap.Color(\"#333\"), stage_width=200, stage_height=50\n... )\n>>> svg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n...     text_spans=[\n...         ap.SvgTextSpan(text=\"Hello, \"),\n...         ap.SvgTextSpan(text=\"Hello, \", font_size=14),\n...     ],\n...     font_size=20,\n...     fill_color=ap.Color(\"#0af\"),\n... )\n```",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [SvgText class](https://simon-ritchie.github.io/apysc/en/svg_text.html)": "- [SvgText クラス](https://simon-ritchie.github.io/apysc/jp/jp_svg_text.html)",  # noqa
    ##################################################
    "## SvgText create_with_svg_text_spans class method API": "## SvgText クラスの create_with_svg_text_spans クラスメソッドのAPI",  # noqa
    ##################################################
    "<span class=\"inconspicuous-txt\">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>": "<span class=\"inconspicuous-txt\">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>",  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Create an `SvgText` instance with specified text spans.<hr>": "指定された各text spanのインスタンスを使用して`SvgText`のインスタンスを生成します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `text_spans`: Union[List[SvgTextSpan], Array[SvgTextSpan]]": "- `text_spans`: Union[List[SvgTextSpan], Array[SvgTextSpan]]",  # noqa
    ##################################################
    "  - Text spans.": "  - 各text span。",
    ##################################################
    "- `font_size`: Union[int, Int], optional": "- `font_size`: Union[int, Int], optional",  # noqa
    ##################################################
    "  - A font-size setting for an overall text.": "  - テキスト全体に設定するフォントサイズの設定。",
    ##################################################
    "- `font_family`: Optional[Union[Array[String], List[str]]], optional": "- `font_family`: Optional[Union[Array[String], List[str]]], optional",  # noqa
    ##################################################
    "  - A font-family setting for an overall text. Each string in an array needs to be a font name (e.g., `Times New Roman`).": "  - テキスト全体に設定するフォント設定。配列内の各文字列はフォント名を指定する必要があります（例 : `Times New Roman`）。",  # noqa
    ##################################################
    "- `x`: Union[float, Number], optional": "- `x`: Union[float, Number], optional",
    ##################################################
    "  - X-coordinate to start drawing.": "  - 描画を開始するX座標。",
    ##################################################
    "- `y`: Union[float, Number], optional": "- `y`: Union[float, Number], optional",
    ##################################################
    "  - Y-coordinate to start drawing (please see also the `Notes` section).": "  - 描画を開始するY座標（`特記事項`の節も確認をお願いします）。",  # noqa
    ##################################################
    "- `fill_color`: Color, optional": "- `fill_color`: Color, optional",
    ##################################################
    "  - A fill-color setting for an overall text.": "  - テキスト全体に設定する塗りの色。",
    ##################################################
    "- `fill_alpha`: float or Number, optional": "- `fill_alpha`: float or Number, optional",  # noqa
    ##################################################
    "  - A fill-alpha setting for an overall text.": "  - テキスト全体に設定する塗りの透明度。",
    ##################################################
    "- `line_color`: Color, optional": "- `line_color`: Color, optional",
    ##################################################
    "  - A line-color setting for an overall text.": "  - テキスト全体に設定する線の色。",
    ##################################################
    "- `line_alpha`: float or Number, optional": "- `line_alpha`: float or Number, optional",  # noqa
    ##################################################
    "  - A line-alpha setting for an overall text.": "  - テキスト全体に設定する線の透明度。",
    ##################################################
    "- `line_thickness`: int or Int, optional": "- `line_thickness`: int or Int, optional",  # noqa
    ##################################################
    "  - A line-thickness (line-width) setting for an overall text.": "  - テキスト全体に設定する線幅。",  # noqa
    ##################################################
    "- `leading`: float or Number, optional": "- `leading`: float or Number, optional",
    ##################################################
    "  - A text-leading size for an overall text.": "  - テキスト全体に設定する行間設定。",
    ##################################################
    "- `align`: SvgTextAlign, optional": "- `align`: SvgTextAlign, optional",
    ##################################################
    "  - A text-align setting for an overall text.": "  - テキスト全体に設定する行揃え設定。",
    ##################################################
    "- `bold`: Union[bool, Boolean], optional": "- `bold`: Union[bool, Boolean], optional",  # noqa
    ##################################################
    "  - A boolean, whether this text is a bold style or not.": "  - テキストに太字のスタイル設定を行うかどうかの真偽値。",  # noqa
    ##################################################
    "- `italic`: Union[bool, Boolean], optional": "- `italic`: Union[bool, Boolean], optional",  # noqa
    ##################################################
    "  - A boolean, whether a text is an italic style or not (normal).": "  - テキストを斜体表示のスタイル設定を行うかどうかの真偽値。",  # noqa
    ##################################################
    "- `parent`: Optional[ChildMixIn], optional": "- `parent`: Optional[ChildMixIn], optional",  # noqa
    ##################################################
    "  - A parent instance to add this instance. If the specified value is None, this interface uses a stage instance.": "  - このインスタンスを追加する親のインスタンス。もしもNoneが指定された場合、このインスタンスはステージのインスタンスへと追加されます。",  # noqa
    ##################################################
    "- `variable_name_suffix`: str, optional": "- `variable_name_suffix`: str, optional",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `svg_text`: SvgText": "- `svg_text`: SvgText",
    ##################################################
    "  - A created `SvgText` instance.": "  - 生成された`SvgText`のインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Notes]**": "**[特記事項]**",
    ##################################################
    " ・SvgText\'s y-coordinate zero-position starts at the bottom of a text. So if you set y=0, a text becomes almost invisible.<hr>": " ・SVGTextクラスの座標の0の位置はテキストの下部からスタートします。そのためもしもy=0を指定した場合、テキストはほとんど見えない状態になります。<hr>",  # noqa
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     background_color=ap.Color(\"#333\"),\n...     stage_width=200,\n...     stage_height=50,\n... )\n>>> svg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n...     text_spans=[\n...         ap.SvgTextSpan(text=\"Hello, \"),\n...         ap.SvgTextSpan(text=\"Hello, \", font_size=14),\n...     ],\n...     font_size=20,\n...     fill_color=ap.Color(\"#0af\"),\n... )\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     background_color=ap.Color(\"#333\"),\n...     stage_width=200,\n...     stage_height=50,\n... )\n>>> svg_text: ap.SvgText = ap.SvgText.create_with_svg_text_spans(\n...     text_spans=[\n...         ap.SvgTextSpan(text=\"Hello, \"),\n...         ap.SvgTextSpan(text=\"Hello, \", font_size=14),\n...     ],\n...     font_size=20,\n...     fill_color=ap.Color(\"#0af\"),\n... )\n```",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [SvgText class](https://simon-ritchie.github.io/apysc/en/svg_text.html)": "- [SvgText クラス](https://simon-ritchie.github.io/apysc/jp/jp_svg_text.html)",  # noqa
}



"""The class implementation for the `phone` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialPhoneIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `phone` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M6.62 10.79c1.44 2.83 3.76 5.14 6.59 6.59l2.2-2.2c.27-.27.67-.36 1.02-.24 1.12.37 2.33.57 3.57.57.55 0 1 .45 1 1V20c0 .55-.45 1-1 1-9.39 0-17-7.61-17-17 0-.55.45-1 1-1h3.5c.55 0 1 .45 1 1 0 1.25.2 2.45.57 3.57.11.35.03.74-.25 1.02l-2.2 2.2z"/></svg>'  # noqa



"""This module is for the translation mapping data of the
following document:

Document file: timedelta_total_seconds.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# TimeDelta class total_seconds interface": "# TimeDelta クラスの total_seconds インターフェイス",  # noqa
    ##################################################
    "This page explains the `TimeDelta` class's `total_seconds` method interface.": "このページでは`TimeDelta`クラスの`total_seconds`メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `total_seconds` method returns the number of total seconds between two `DateTime` instances.": "`total_seconds`メソッドは2つの`DateTime`クラスのインスタンス間の合計秒数を返却します。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `total_seconds` method returns the apysc's `Number` value.": "`total_seconds`メソッドはapyscの`Number`型の値を返却します。",  # noqa
    ##################################################
    "If any `DateTime` instances have a `millisecond` value, this interface sets a fraction value.": "もしもいずれかの`DateTime`のインスタンスが`millisecond`属性の値を持っていた場合このインターフェイスは小数点数も含んだ値を設定します。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\ndatetime_1: ap.DateTime = ap.DateTime(2022, 12, 7, millisecond=100)\ndatetime_2: ap.DateTime = ap.DateTime(2022, 12, 5)\ntimedelta_: ap.TimeDelta = datetime_1 - datetime_2\ntotal_seconds: ap.Number = timedelta_.total_seconds()\nassert total_seconds == 60 * 60 * 24 * 2 + 0.1\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\ndatetime_1: ap.DateTime = ap.DateTime(2022, 12, 7, millisecond=100)\ndatetime_2: ap.DateTime = ap.DateTime(2022, 12, 5)\ntimedelta_: ap.TimeDelta = datetime_1 - datetime_2\ntotal_seconds: ap.Number = timedelta_.total_seconds()\nassert total_seconds == 60 * 60 * 24 * 2 + 0.1\n```",  # noqa
    ##################################################
    "## total_seconds method API": "## total_seconds メソッドのAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get the total seconds in the duration.<hr>": "時間の間隔値の合計秒数を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `total_seconds`: Number": "- `total_seconds`: Number",
    ##################################################
    "  - Total seconds in the duration.": "  - 時間の間隔値の合計秒数。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> datetime_1: ap.DateTime = ap.DateTime(2022, 12, 7)\n>>> datetime_2: ap.DateTime = ap.DateTime(2022, 12, 6)\n>>> timedelta_: ap.TimeDelta = datetime_1 - datetime_2\n>>> timedelta_.total_seconds()\nNumber(86400.0)\n```": "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> datetime_1: ap.DateTime = ap.DateTime(2022, 12, 7)\n>>> datetime_2: ap.DateTime = ap.DateTime(2022, 12, 6)\n>>> timedelta_: ap.TimeDelta = datetime_1 - datetime_2\n>>> timedelta_.total_seconds()\nNumber(86400.0)\n```",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [TimeDelta class](https://simon-ritchie.github.io/apysc/en/timedelta.html)": "- [TimeDelta クラス](https://simon-ritchie.github.io/apysc/jp/jp_timedelta.html)",  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: int_and_number.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Int and Number classes": "# Int と Number クラス",
    ##################################################
    "This page explains the `Int` and `Number` classes.": "このページでは`Int`と`Number`の各クラスについて説明します。",  # noqa
    ##################################################
    "Before reading on, maybe it is helpful to read the following page:": "事前に以下のページを確認しておくと読み進める上で役に立つかもしれません:",  # noqa
    ##################################################
    "- [Why the apysc library doesn't use the Python built-in data type](why_apysc_doesnt_use_python_builtin_data_type.md)": "- [なぜapyscではPythonのビルトインのデータの型を使用していないのか](jp_why_apysc_doesnt_use_python_builtin_data_type.md)",  # noqa
    ##################################################
    "## Int class": "## Int クラス",
    ##################################################
    "The `Int` class is the apysc integer type. It can accept numeric values at the constructor, as follows:": "`Int`クラスはapyscの整数の型となります。このクラスは以下のコード例のようにコンストラクタに数値の値を受け付けます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nint_1: ap.Int = ap.Int(10)\nassert int_1 == 10\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nint_1: ap.Int = ap.Int(10)\nassert int_1 == 10\n```",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nint_1: ap.Int = ap.Int(10)\nint_2: ap.Int = ap.Int(int_1)\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nint_1: ap.Int = ap.Int(10)\nint_2: ap.Int = ap.Int(int_1)\n```",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nint_1: ap.Int = ap.Int(10)\nint_2: ap.Int = ap.Int(int_1)\nint_2 += 15\nassert int_2 == 25\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nint_1: ap.Int = ap.Int(10)\nint_2: ap.Int = ap.Int(int_1)\nint_2 += 15\nassert int_2 == 25\n```",  # noqa
    ##################################################
    "If you specify a float value to the constructor argument, then the `Int` class floor a value:": "もしコンストラクタの引数に浮動小数点数を指定した場合には`Int`クラスはその値の浮動小数点数を切り捨てます:",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nint_1: ap.Int = ap.Int(10.5)\nassert int_1 == 10\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nint_1: ap.Int = ap.Int(10.5)\nassert int_1 == 10\n```",  # noqa
    ##################################################
    "## Number class": "## Number クラス",
    ##################################################
    "The ``Number`` class is the apysc float type. It can accept numeric values at the constructor, the same as `Int`:": "`Number`クラスはapyscの浮動小数点数の型です。このクラスは`Int`クラスと同様にコンストラクタの引数に数値を受け付けます。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nnumber_1: ap.Number = ap.Number(10.5)\nassert number_1 == 10.5\n\nnumber_2: ap.Number = ap.Number(number_1)\nnumber_2 += 10.5\nassert number_2 == 21\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nnumber_1: ap.Number = ap.Number(10.5)\nassert number_1 == 10.5\n\nnumber_2: ap.Number = ap.Number(number_1)\nnumber_2 += 10.5\nassert number_2 == 21\n```",  # noqa
    ##################################################
    "## Note for the Float class alias": "## Floatクラスのエイリアスの特記事項",
    ##################################################
    "The `Float` class is the alias of the `Number` class. It behaves the same as the `Number` class. Maybe a Python developer is familiar with its name rather than the `Number`\\. On the other hand, the `Number` is more common in JavaScript than the `Float`\\.": "`Float`クラスは`Number`クラスのエイリアス。です。このエイリアスは`Number`クラスと同様に動作します。Python開発者の方はもしかしたら`Number`クラスよりもこちらのエイリアスの方が慣れ親しんでいて自然に感じられるかもしれません。一方でJavaScriptなどの開発者の方は`Float`よりも`Number`の方が自然に思えるかもしれません。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nassert ap.Number == ap.Float\nassert ap.Number(10.5) == ap.Float(10.5)\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\nassert ap.Number == ap.Float\nassert ap.Number(10.5) == ap.Float(10.5)\n```",  # noqa
    ##################################################
    "## Int and Number classes basic interfaces": "## Int と Number クラスの基本的なインターフェイス",
    ##################################################
    "The `Int` and `Number` classes have the same interfaces. For more details, please see:": "`Int`と`Number`の各クラスは同じ各インターフェイスを持っています。詳細に関しては以下をご確認ください:",  # noqa
    ##################################################
    "- [Int and Number classes basic arithmetic operations](int_and_number_arithmetic_operations.md)": "- [Int と Number クラスの基本的な各計算の制御](jp_int_and_number_arithmetic_operations.md)",  # noqa
    ##################################################
    "- [Int and Number classes basic comparison operations](int_and_number_comparison_operations.md)": "- [Int と Number クラスの基本的な各比較の制御](jp_int_and_number_comparison_operations.md)",  # noqa
    ##################################################
    "- [Funcdamental data classes common value interface](fundamental_data_classes_value_interface.md)": "- [基本的なデータクラスの共通の value インターフェイス](jp_fundamental_data_classes_value_interface.md)",  # noqa
    ##################################################
    "## Int class constructor API": "## Int クラスのコンストラクタのAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Integer class for apysc library.<hr>": "apyscライブラリ上の整数のためのクラスです。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `value`: int or float or Int or Number": "- `value`: int or float or Int or Number",  # noqa
    ##################################################
    "  - Initial integer value. If the `float` or `Number` value is specified, this class casts it to an integer.": "  - 整数の初期値。もしも`float`や`Number`の値が指定された場合このクラスは値を整数へと変換します。",  # noqa
    ##################################################
    '- `variable_name_suffix`: str, default ""': '- `variable_name_suffix`: str, default ""',  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "- `skip_init_substitution_expression_appending`: bool, default False": "- `skip_init_substitution_expression_appending`: bool, default False",  # noqa
    ##################################################
    "  - A boolean indicates whether to skip an initial substitution expression or not. This class uses this option internally.": "  - 初期値の代入のコード表現をスキップするかどうかの真偽値です。このオプションはクラス内部の実装で使用されます。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> int_val: ap.Int = ap.Int(10)\n>>> int_val\nInt(10)\n\n>>> int_val == 10\nBoolean(True)\n\n>>> int_val == ap.Int(10)\nBoolean(True)\n\n>>> int_val >= 10\nBoolean(True)\n\n>>> int_val += 10\n>>> int_val\nInt(20)\n\n>>> int_val = ap.Int(10.5)\n>>> int_val\nInt(10)\n```": "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> int_val: ap.Int = ap.Int(10)\n>>> int_val\nInt(10)\n\n>>> int_val == 10\nBoolean(True)\n\n>>> int_val == ap.Int(10)\nBoolean(True)\n\n>>> int_val >= 10\nBoolean(True)\n\n>>> int_val += 10\n>>> int_val\nInt(20)\n\n>>> int_val = ap.Int(10.5)\n>>> int_val\nInt(10)\n```",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [Int and Number common arithmetic operations](https://simon-ritchie.github.io/apysc/en/int_and_number_arithmetic_operations.html)": "- [Int と Number クラスの共通の各計算制御](https://simon-ritchie.github.io/apysc/jp/jp_int_and_number_arithmetic_operations.html)",  # noqa
    ##################################################
    "- [Int and Number common comparison operations](https://simon-ritchie.github.io/apysc/en/int_and_number_comparison_operations.html)": "- [Int と Number クラスの共通の各比較制御](https://simon-ritchie.github.io/apysc/jp/jp_int_and_number_comparison_operations.html)",  # noqa
    ##################################################
    "## Number class constructor API": "## Number クラスのコンストラクタのAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Floating point number class for apysc library.<hr>": "apyscライブラリ用の浮動小数点数のクラスです。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `value`: int or float or Int or Number": "- `value`: int or float or Int or Number",  # noqa
    ##################################################
    "  - Initial floating point number value. This class casts it to float if you specify int or Int value.": "  - 浮動小数点数の初期値。もしもintやIntなどの型の値が指定された場合このクラスは値を浮動小数点数へ変換します。",  # noqa
    ##################################################
    '- `variable_name_suffix`: str, default ""': '- `variable_name_suffix`: str, default ""',  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "- `skip_init_substitution_expression_appending`: bool, default False": "- `skip_init_substitution_expression_appending`: bool, default False",  # noqa
    ##################################################
    "  - A boolean indicates whether to skip an initial substitution expression or not. This class uses this option internally.": "  - 初期値の代入のコード表現をスキップするかどうかの真偽値です。このオプションはクラス内部の実装で使用されます。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Notes]**": "**[特記事項]**",
    ##################################################
    "The `Float` class is the alias of the Number, and it behaves the same as the Number class.<hr>": "`Float`クラスはNumberクラスのエイリアスであり、このエイリアスはNumberクラスと同様に動作します。<hr>",  # noqa
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> number: ap.Number = ap.Number(10.5)\n>>> number\nNumber(10.5)\n\n>>> number == 10.5\nBoolean(True)\n\n>>> number == ap.Number(10.5)\nBoolean(True)\n\n>>> number >= 10.5\nBoolean(True)\n\n>>> number += 10.3\n>>> number\nNumber(20.8)\n```": "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> number: ap.Number = ap.Number(10.5)\n>>> number\nNumber(10.5)\n\n>>> number == 10.5\nBoolean(True)\n\n>>> number == ap.Number(10.5)\nBoolean(True)\n\n>>> number >= 10.5\nBoolean(True)\n\n>>> number += 10.3\n>>> number\nNumber(20.8)\n```",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [Int and Number common arithmetic operations](https://simon-ritchie.github.io/apysc/en/int_and_number_arithmetic_operations.html)": "- [Int と Number クラスの共通の各計算制御](https://simon-ritchie.github.io/apysc/jp/jp_int_and_number_arithmetic_operations.html)",  # noqa
    ##################################################
    "- [Int and Number common comparison operations](https://simon-ritchie.github.io/apysc/en/int_and_number_comparison_operations.html)": "- [Int と Number クラスの共通の各比較制御](https://simon-ritchie.github.io/apysc/jp/jp_int_and_number_comparison_operations.html)",  # noqa
    ##################################################
    "## value property API": "## value 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a current number value.<hr>": "現在の数値を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `value`: int or float": "- `value`: int or float",
    ##################################################
    "  - Current number value.": "  - 現在の数値。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> int_val: ap.Int = ap.Int(10)\n>>> int_val.value\n10\n\n>>> int_val.value = 20\n>>> int_val.value\n20\n\n>>> int_val.value = ap.Int(30)\n>>> int_val.value\n30\n```": "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> int_val: ap.Int = ap.Int(10)\n>>> int_val.value\n10\n\n>>> int_val.value = 20\n>>> int_val.value\n20\n\n>>> int_val.value = ap.Int(30)\n>>> int_val.value\n30\n```",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [apysc fundamental data classes value interface](https://simon-ritchie.github.io/apysc/en/fundamental_data_classes_value_interface.html)": "- [apyscの基本的なデータクラスの value インターフェイス](https://simon-ritchie.github.io/apysc/jp/jp_fundamental_data_classes_value_interface.html)",  # noqa
}



"""The class implementation for the outlined `unsubscribe` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialUnsubscribeOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `unsubscribe` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M20.99 14.04V5c0-1.1-.9-2-2-2H5c-1.1 0-2 .9-2 2v10c0 1.1.9 2 2 2h10.05c.28 1.92 2.1 3.35 4.18 2.93 1.34-.27 2.43-1.37 2.7-2.71.25-1.24-.16-2.39-.94-3.18zm-2-9.04L12 8.5 5 5h13.99zm-3.64 10H5V7l7 3.5L19 7v6.05c-.16-.02-.33-.05-.5-.05-1.39 0-2.59.82-3.15 2zm5.15 2h-4v-1h4v1z"/></svg>'  # noqa



"""The class implementation for the outlined `insights` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialInsightsOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `insights` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><path d="M21,8c-1.45,0-2.26,1.44-1.93,2.51l-3.55,3.56c-0.3-0.09-0.74-0.09-1.04,0l-2.55-2.55C12.27,10.45,11.46,9,10,9 c-1.45,0-2.27,1.44-1.93,2.52l-4.56,4.55C2.44,15.74,1,16.55,1,18c0,1.1,0.9,2,2,2c1.45,0,2.26-1.44,1.93-2.51l4.55-4.56 c0.3,0.09,0.74,0.09,1.04,0l2.55,2.55C12.73,16.55,13.54,18,15,18c1.45,0,2.27-1.44,1.93-2.52l3.56-3.55 C21.56,12.26,23,11.45,23,10C23,8.9,22.1,8,21,8z"/><polygon points="15,9 15.94,6.93 18,6 15.94,5.07 15,3 14.08,5.07 12,6 14.08,6.93"/><polygon points="3.5,11 4,9 6,8.5 4,8 3.5,6 3,8 1,8.5 3,9"/></g></g></svg>'  # noqa



"""The class implementation for the `login` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialLoginIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `login` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><path d="M11,7L9.6,8.4l2.6,2.6H2v2h10.2l-2.6,2.6L11,17l5-5L11,7z M20,19h-8v2h8c1.1,0,2-0.9,2-2V5c0-1.1-0.9-2-2-2h-8v2h8V19z"/></g></svg>'  # noqa



"""The class implementation for the outlined `volume_off` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialVolumeOffOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `volume_off` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M4.34 2.93L2.93 4.34 7.29 8.7 7 9H3v6h4l5 5v-6.59l4.18 4.18c-.65.49-1.38.88-2.18 1.11v2.06c1.34-.3 2.57-.92 3.61-1.75l2.05 2.05 1.41-1.41L4.34 2.93zM10 15.17L7.83 13H5v-2h2.83l.88-.88L10 11.41v3.76zM19 12c0 .82-.15 1.61-.41 2.34l1.53 1.53c.56-1.17.88-2.48.88-3.87 0-4.28-2.99-7.86-7-8.77v2.06c2.89.86 5 3.54 5 6.71zm-7-8l-1.88 1.88L12 7.76zm4.5 8c0-1.77-1.02-3.29-2.5-4.03v1.79l2.48 2.48c.01-.08.02-.16.02-.24z"/></svg>'  # noqa



"""The class implementation for the fixed HTML SVG icon's base class.
"""

from abc import abstractmethod
from typing import Optional
from typing import Union

from apysc._color.color import Color
from apysc._color.colors import Colors
from apysc._display.child_mixin import ChildMixIn
from apysc._display.svg_icon import SvgIcon
from apysc._type.int import Int
from apysc._type.number import Number


class FixedHtmlSvgIconBase(SvgIcon):
    @abstractmethod
    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.
        """
        return ""

    def __init__(
        self,
        x: Union[float, Number] = 0.0,
        y: Union[float, Number] = 0.0,
        size: Union[int, Int] = 24,
        fill_color: Color = Colors.GRAY_666666,
        fill_alpha: Union[float, Number] = 1.0,
        parent: Optional[ChildMixIn] = None,
        variable_name_suffix: str = "",
    ) -> None:
        """
        The class implementation for the SVG icon's class.

        Parameters
        ----------
        x : Union[float, Number], optional
            X-coordinate of the icon.
        y : Union[float, Number], optional
            Y-coordinate of the icon.
        size : Union[int, Int], optional
            Size of the icon.
        fill_color : Color, optional
            Fill-color of the icon.
        fill_alpha : Union[float, Number], optional
            Fill-alpha of the icon.
        parent : Optional[ChildMixIn], optional
            A parent instance to add this instance.
            If the specified value is None, this interface uses
            a stage instance.
        variable_name_suffix : str, optional
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.
        """
        super(FixedHtmlSvgIconBase, self).__init__(
            svg_icon_html=self._get_fixed_svg_icon_html(),
            x=x,
            y=y,
            size=size,
            fill_color=fill_color,
            fill_alpha=fill_alpha,
            parent=parent,
            variable_name_suffix=variable_name_suffix,
        )



"""The class implementation for the `rowing` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialRowingIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `rowing` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><g><path d="M8.5,14.5L4,19l1.5,1.5L9,17h2L8.5,14.5z M15,1c-1.1,0-2,0.9-2,2s0.9,2,2,2s2-0.9,2-2S16.1,1,15,1z M21,21.01L18,24 l-2.99-3.01V19.5l-7.1-7.09C7.6,12.46,7.3,12.48,7,12.48v-2.16c1.66,0.03,3.61-0.87,4.67-2.04l1.4-1.55 C13.42,6.34,14.06,6,14.72,6h0.03C15.99,6.01,17,7.02,17,8.26v5.75c0,0.84-0.35,1.61-0.92,2.16l-3.58-3.58v-2.27 c-0.63,0.52-1.43,1.02-2.29,1.39L16.5,18H18L21,21.01z"/></g></g></g></svg>'  # noqa



"""The class implementation for the outlined `settings_power` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialSettingsPowerOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `settings_power` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M7 24h2v-2H7v2zm4 0h2v-2h-2v2zm2-22h-2v10h2V2zm3.56 2.44l-1.45 1.45C16.84 6.94 18 8.83 18 11c0 3.31-2.69 6-6 6s-6-2.69-6-6c0-2.17 1.16-4.06 2.88-5.12L7.44 4.44C5.36 5.88 4 8.28 4 11c0 4.42 3.58 8 8 8s8-3.58 8-8c0-2.72-1.36-5.12-3.44-6.56zM15 24h2v-2h-2v2z"/></svg>'  # noqa
